@@ -6,7 +6,7 @@
 #' influence of outliers on the regression line.
 #'
 #' @param res result of the outliers_mad function from which we want to create a plot
-#' @param x matrix of bivariate values from which we want to compute outliers
+#' @param x matrix of multivariate values from which we want to compute outliers. Last column of the matrix is considered as the DV in the regression line.
 #' @param pos_display set whether the position of outliers in the dataset should be displayed on the graph (pos_display = TRUE)
 #' or not (pos_display = FALSE)
 #'
@@ -77,7 +77,7 @@ plot_outliers_mcd <- function(res,
     ) +
     geom_hline(yintercept=res$center[2], linetype=2, color="lightgrey") +
     geom_vline(xintercept=res$center[1], linetype=2, color="lightgrey") +
-    xlab("Dimension 1") + ylab("Dimension 2")
+    xlab(colnames(data)[1]) + ylab(colnames(data)[ncol(data)])
 
   # if pos_display = TRUE, adding annotations in outliers points
   if (pos_display==TRUE){
@@ -93,13 +93,15 @@ plot_outliers_mcd <- function(res,
 
   if (length(res$outliers_pos) == 0){ # if there are no outliers in the plot
 
-    regr <- lm(data[,2]~data[,1])$coefficients
-    if(regr[2] > 0){
-      sign <- "+"
-    } else {sign <- ""}
-    # labelling the regression line
-    label <- paste0("Regression line: y = ",round(regr[1],3)," ",
-                   sign," ",round(regr[2],3),"x")
+    DV <- names(data)[ncol(data)]
+    names(data)[ncol(data)]="DV"
+    regr <- lm(DV~.,data=data)$coefficients
+    # Translate regr into a regression line
+    regr_line <- paste("Regression line:", DV," = ",round(regr[1],3))
+    for (k in seq_len(length(regr)-1)){
+      if (regr[k+1] > 0){regr_line <- paste0(regr_line," + ",abs(round(regr[k+1],3))," ",names(regr)[k+1])
+      } else {regr_line <- paste0(regr_line," - ",abs(round(regr[k+1],3))," ",names(regr)[k+1])}
+    }
 
     # plotting results, with one regression line (including all data points)
     p +
@@ -111,36 +113,32 @@ plot_outliers_mcd <- function(res,
                          labels=c("standard values",
                                   "standard values")
                          )+
-      ggtitle(label=label) +
+      ggtitle(label=regr_line) +
       theme(plot.title = element_text(hjust = 0.5,color="darkviolet",size=12))
 
   } else { # if there are detected outliers
-    # matrix without outliers (IF there are outliers):
+
+    # regression line including all data:
+    DV <- names(data)[ncol(data)]
+    names(data)[ncol(data)]="DV"
+    regr <- lm(DV~.,data=data)$coefficients
+    regr_line <- paste("Regression line including all data:",DV," = ",round(regr[1],3))
+    for (k in seq_len(length(regr)-1)){
+      if (regr[k+1] > 0){regr_line <- paste0(regr_line," + ",abs(round(regr[k+1],3))," ",names(regr)[k+1])
+      } else {regr_line <- paste0(regr_line," - ",abs(round(regr[k+1],3))," ",names(regr)[k+1])}
+    }
+    # regression without outliers:
     dat2 <- data[-res$outliers_pos,]
-    # regression line computed with and without outliers:
-    regr_all <- lm(data[,2]~data[,1])$coefficients
-    mod <- lm(dat2[,2]~dat2[,1])$coefficients
+    names(dat2)[ncol(dat2)]="DV"
+    regr_no <- lm(DV~.,data=dat2)$coefficients
+    regr_line_no <- paste("Regression line without detected outliers:",DV," = ",round(regr_no[1],3))
+    for (k in seq_len(length(regr_no)-1)){
+      if (regr_no[k+1] > 0){regr_line_no <- paste0(regr_line_no," + ",abs(round(regr_no[k+1],3))," ",names(regr_no)[k+1])
+      } else {regr_line_no <- paste0(regr_line_no," - ",abs(round(regr_no[k+1],3))," ",names(regr_no)[k+1])}
+    }
 
-    # labelling the regression lines (with and without outliers)
-    if(regr_all[2] > 0){
-      sign <- "+"
-    } else {sign <- ""}
-
-    if(mod[2] > 0){
-      sign <- "+"
-    } else {sign <- ""}
-
-    label1 <- paste0("Regression line including all data: y = ",
-                     round(regr_all[1],3)," ",
-                     sign," ",
-                     round(regr_all[2],3),"x")
-    label2 <- paste0("Regression line without detected outliers: y = ",
-                     round(mod[1],3)," ",
-                     sign," ",
-                     round(mod[2],3),"x")
-
-    p + geom_abline(slope=mod[2],
-                    intercept=mod[1],
+    p + geom_abline(slope=regr_no[2],
+                    intercept=regr_no[1],
                     colour="darkgreen",size=.8) +
       scale_shape_manual(values=c(16,15),
                          labels=c("standard values",
@@ -148,7 +146,7 @@ plot_outliers_mcd <- function(res,
       scale_color_manual(values=c('black','red'),
                          labels=c("standard values",
                                   "outliers")) +
-      ggtitle(label=label1,subtitle =label2) +
+      ggtitle(label=regr_line,subtitle =regr_line_no) +
       theme(plot.title = element_text(hjust = 0.5,color="darkviolet",size=12),
             plot.subtitle = element_text(hjust = 0.5,color="darkgreen",size=12)
       ) +
